/*
** File:        rawgfx.h
** Author:      Andreas Remar
** Location:    Linkoping, Sweden
** E-mail:      remar@delta.telenordia.se
*/


/*
** void screen(int t);
** changes graphics mode into the one specified.
** To use the rest of the functions you should
** go into mode 13h, like this: screen(0x13);
** To go back into text mode:   screen(0x3);
*/
void screen(int t);

/*
** void PutPixel(int x, int y, char c);
** places a pixel at the (x, y) location
** with the color c: PutPixel(160, 100, 4);
** puts a red pixel in the center of the screen.
*/
void PutPixel(int x, int y, char c);

/*
** char GetPixel(int x, int y);
** gets a pixel from the screen at
** the (x, y) location.
** e.g: char c = GetPixel(160, 100);
*/
char GetPixel(int x, int y);

/*
** void PutBmp(int x, int y, unsigned char *bitmap, int x_size, int y_size);
** puts a bmp at the location specified by x, y. The size must be
** x_size, y_size if you want it to look like you intended...
** e.g: PutBmp(160, 100, &mybmp[0][0], 16, 16);
**  or
**      PutBmp(160, 100, mybmp, 16, 16);
*/
void PutBmp(int x, int y, unsigned char *bitmap, int x_size, int y_size);

/*
** void GetBmp(int x, int y, char *bitmap, int x_size, int y_size);
** gets a bmp at the location specified byx, y. This function is
** very useful if you wants to use a mouse.
** e.g: GetBmp(160, 100, temp, 16, 32);
*/
void GetBmp(int x, int y, char *bitmap, int x_size, int y_size);

/*
** int  LoadBmp(unsigned char *bmp, char *file);
** loads a bmp made in RawEdit.
** e.g: LoadBmp(mycutebmp, "hello.raw");
*/
int  LoadBmp(unsigned char *bmp, char *file);
/*
** void Line(int x1, int y1, int x2, int y2, char color);
** draws a line from (x1, y1) to (x2, y2) with the color
** specified.
** e.g: Line(10, 10, 50, 100, 4);
*/
void Line(int x1, int y1, int x2, int y2, char color);

/*
** void vsync(void)
** awaits the right moment to draw to the screen
** example:
** 	vsync();
**	updatescreen();
*/
void vsync(void);
